@@ -17,8 +17,7 @@
 # from server.cl_server import main
 # print(main)
 
-from __future__ import print_function
-from __future__ import absolute_import
+from importlib import reload
 def core_main():
     import sys
 
@@ -50,14 +49,15 @@ def core_main():
             print_exc()
             cannot_import = 'cannot import name '
             no_module = 'No module named '
-            if e.message.startswith(cannot_import):
+            se = str(e)
+            if se.startswith(cannot_import):
                 print (_('Failed to import %s')
-                       % e.message.rpartition(cannot_import)[2])
-            elif e.message.startswith(no_module):
+                       % se.rpartition(cannot_import)[2])
+            elif se.startswith(no_module):
                 print (_('No module named %s') %
-                       e.message.rpartition(no_module)[2])
+                       se.rpartition(no_module)[2])
             else:
-                print(e.message)
+                print(e)
             sys.exit(1)
     except KeyboardInterrupt:
         print()
